
Installation
++++++++++++

To start using ``pigmenta`` in your project you run the following command:

.. code-block:: shell

    pip install pigmenta


.. note:: Or if you want to install it in notebooks such as jupyter notebooks you can run the code cell with the following code:

.. code-block:: shell

    !pip install pigmenta


.. note:: You can install it directly from a GitHub repo:

.. code-block:: shell
    
    pip install git+https://github.com/yourusername/pigmenta.git


Once you install ``pigmenta`` now you are ready to use it in your projects.